@@ -51,7 +51,7 @@ LDAP_DIR = '/var/lib/univention-ldap'
 STATE_DIR = '/var/lib/univention-directory-replication'
 BACKUP_DIR = '/var/univention-backup/replication'
 LDIF_FILE = os.path.join(STATE_DIR, 'failed.ldif')
-SCHEMA_FILE = os.path.join(STATE_DIR, 'schema.conf')
+SCHEMA_FILE = os.path.join(LDAP_DIR, 'schema.conf')
 ROOTPW_FILE = '/etc/ldap/rootpw.conf'
 CURRENT_MODRDN = os.path.join(STATE_DIR, 'current_modrdn')
 MAX_LDAP_RETRIES = int(listener.configRegistry.get('replication/ldap/retries', '30'))
